/****************************************************************************
** Meta object code from reading C++ file 'displayhint.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kirigami-6.26.0/src/layouts/displayhint.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'displayhint.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11DisplayHintE_t {};
} // unnamed namespace

template <> constexpr inline auto DisplayHint::qt_create_metaobjectdata<qt_meta_tag_ZN11DisplayHintE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DisplayHint",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "displayHintSet",
        "",
        "DisplayHints",
        "values",
        "Hint",
        "hint",
        "object",
        "NoPreference",
        "IconOnly",
        "KeepVisible",
        "AlwaysHide",
        "HideChildIndicator"
    };

    QtMocHelpers::UintData qt_methods {
        // Method 'displayHintSet'
        QtMocHelpers::MethodData<bool(DisplayHints, enum Hint)>(5, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 7, 8 }, { 0x80000000 | 9, 10 },
        }}),
        // Method 'displayHintSet'
        QtMocHelpers::MethodData<bool(QObject *, enum Hint)>(5, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QObjectStar, 11 }, { 0x80000000 | 9, 10 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Hint'
        QtMocHelpers::EnumData<enum Hint>(9, 9, QMC::EnumFlags{}).add({
            {   12, Hint::NoPreference },
            {   13, Hint::IconOnly },
            {   14, Hint::KeepVisible },
            {   15, Hint::AlwaysHide },
            {   16, Hint::HideChildIndicator },
        }),
        // flag 'DisplayHints'
        QtMocHelpers::EnumData<DisplayHints>(7, 9, QMC::EnumIsFlag).add({
            {   12, Hint::NoPreference },
            {   13, Hint::IconOnly },
            {   14, Hint::KeepVisible },
            {   15, Hint::AlwaysHide },
            {   16, Hint::HideChildIndicator },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<DisplayHint, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DisplayHint::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11DisplayHintE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11DisplayHintE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11DisplayHintE_t>.metaTypes,
    nullptr
} };

void DisplayHint::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DisplayHint *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { bool _r = _t->displayHintSet((*reinterpret_cast<std::add_pointer_t<DisplayHints>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<enum Hint>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 1: { bool _r = _t->displayHintSet((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<enum Hint>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

const QMetaObject *DisplayHint::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DisplayHint::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11DisplayHintE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DisplayHint::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    return _id;
}
QT_WARNING_POP
