/****************************************************************************
** Meta object code from reading C++ file 'colorutils.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kirigami-6.26.0/src/platform/colorutils.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'colorutils.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10ColorUtilsE_t {};
} // unnamed namespace

template <> constexpr inline auto ColorUtils::qt_create_metaobjectdata<qt_meta_tag_ZN10ColorUtilsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ColorUtils",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "brightnessForColor",
        "ColorUtils::Brightness",
        "",
        "QColor",
        "color",
        "grayForColor",
        "alphaBlend",
        "foreground",
        "background",
        "linearInterpolation",
        "one",
        "two",
        "balance",
        "adjustColor",
        "QJSValue",
        "adjustments",
        "scaleColor",
        "tintWithAlpha",
        "targetColor",
        "tintColor",
        "alpha",
        "chroma",
        "Brightness",
        "Dark",
        "Light"
    };

    QtMocHelpers::UintData qt_methods {
        // Method 'brightnessForColor'
        QtMocHelpers::MethodData<ColorUtils::Brightness(const QColor &)>(5, 7, QMC::AccessPublic, 0x80000000 | 6, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Method 'grayForColor'
        QtMocHelpers::MethodData<qreal(const QColor &)>(10, 7, QMC::AccessPublic, QMetaType::QReal, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Method 'alphaBlend'
        QtMocHelpers::MethodData<QColor(const QColor &, const QColor &)>(11, 7, QMC::AccessPublic, 0x80000000 | 8, {{
            { 0x80000000 | 8, 12 }, { 0x80000000 | 8, 13 },
        }}),
        // Method 'linearInterpolation'
        QtMocHelpers::MethodData<QColor(const QColor &, const QColor &, double)>(14, 7, QMC::AccessPublic, 0x80000000 | 8, {{
            { 0x80000000 | 8, 15 }, { 0x80000000 | 8, 16 }, { QMetaType::Double, 17 },
        }}),
        // Method 'adjustColor'
        QtMocHelpers::MethodData<QColor(const QColor &, const QJSValue &)>(18, 7, QMC::AccessPublic, 0x80000000 | 8, {{
            { 0x80000000 | 8, 9 }, { 0x80000000 | 19, 20 },
        }}),
        // Method 'scaleColor'
        QtMocHelpers::MethodData<QColor(const QColor &, const QJSValue &)>(21, 7, QMC::AccessPublic, 0x80000000 | 8, {{
            { 0x80000000 | 8, 9 }, { 0x80000000 | 19, 20 },
        }}),
        // Method 'tintWithAlpha'
        QtMocHelpers::MethodData<QColor(const QColor &, const QColor &, double)>(22, 7, QMC::AccessPublic, 0x80000000 | 8, {{
            { 0x80000000 | 8, 23 }, { 0x80000000 | 8, 24 }, { QMetaType::Double, 25 },
        }}),
        // Method 'chroma'
        QtMocHelpers::MethodData<qreal(const QColor &)>(26, 7, QMC::AccessPublic, QMetaType::QReal, {{
            { 0x80000000 | 8, 9 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Brightness'
        QtMocHelpers::EnumData<enum Brightness>(27, 27, QMC::EnumFlags{}).add({
            {   28, Brightness::Dark },
            {   29, Brightness::Light },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<ColorUtils, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject ColorUtils::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10ColorUtilsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10ColorUtilsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10ColorUtilsE_t>.metaTypes,
    nullptr
} };

void ColorUtils::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ColorUtils *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { ColorUtils::Brightness _r = _t->brightnessForColor((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1])));
            if (_a[0]) *reinterpret_cast<ColorUtils::Brightness*>(_a[0]) = std::move(_r); }  break;
        case 1: { qreal _r = _t->grayForColor((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1])));
            if (_a[0]) *reinterpret_cast<qreal*>(_a[0]) = std::move(_r); }  break;
        case 2: { QColor _r = _t->alphaBlend((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QColor>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QColor*>(_a[0]) = std::move(_r); }  break;
        case 3: { QColor _r = _t->linearInterpolation((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QColor>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QColor*>(_a[0]) = std::move(_r); }  break;
        case 4: { QColor _r = _t->adjustColor((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QColor*>(_a[0]) = std::move(_r); }  break;
        case 5: { QColor _r = _t->scaleColor((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QColor*>(_a[0]) = std::move(_r); }  break;
        case 6: { QColor _r = _t->tintWithAlpha((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QColor>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QColor*>(_a[0]) = std::move(_r); }  break;
        case 7: { qreal _r = _t->chroma((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1])));
            if (_a[0]) *reinterpret_cast<qreal*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        }
    }
}

const QMetaObject *ColorUtils::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ColorUtils::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10ColorUtilsE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ColorUtils::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}
QT_WARNING_POP
