/****************************************************************************
** Meta object code from reading C++ file 'overlayzstackingattached.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kirigami-6.26.0/src/overlayzstackingattached.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'overlayzstackingattached.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN24OverlayZStackingAttachedE_t {};
} // unnamed namespace

template <> constexpr inline auto OverlayZStackingAttached::qt_create_metaobjectdata<qt_meta_tag_ZN24OverlayZStackingAttachedE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OverlayZStackingAttached",
        "QML.Element",
        "auto",
        "OverlayZStacking",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "Cannot create objects of type OverlayZStacking, use it as an attac"
        "hed property",
        "QML.Attached",
        "zChanged",
        "",
        "layerChanged",
        "enqueueSignal",
        "dispatchPendingSignal",
        "updateParentPopup",
        "z",
        "layer",
        "Layer",
        "DefaultLowest",
        "Drawer",
        "FullScreen",
        "Dialog",
        "Menu",
        "Notification",
        "ToolTip"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'zChanged'
        QtMocHelpers::SignalData<void()>(9, 10, QMC::AccessPublic, QMetaType::Void),
        // Signal 'layerChanged'
        QtMocHelpers::SignalData<void()>(11, 10, QMC::AccessPublic, QMetaType::Void),
        // Slot 'enqueueSignal'
        QtMocHelpers::SlotData<void()>(12, 10, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'dispatchPendingSignal'
        QtMocHelpers::SlotData<void()>(13, 10, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateParentPopup'
        QtMocHelpers::SlotData<void()>(14, 10, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'z'
        QtMocHelpers::PropertyData<qreal>(15, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Final, 0),
        // property 'layer'
        QtMocHelpers::PropertyData<enum Layer>(16, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 1),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Layer'
        QtMocHelpers::EnumData<enum Layer>(17, 17, QMC::EnumFlags{}).add({
            {   18, Layer::DefaultLowest },
            {   19, Layer::Drawer },
            {   20, Layer::FullScreen },
            {   21, Layer::Dialog },
            {   22, Layer::Menu },
            {   23, Layer::Notification },
            {   24, Layer::ToolTip },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    1,    3 },
            {    4,    5 },
            {    6,    7 },
            {    8,    0 },
    });
    return QtMocHelpers::metaObjectData<OverlayZStackingAttached, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject OverlayZStackingAttached::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24OverlayZStackingAttachedE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24OverlayZStackingAttachedE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN24OverlayZStackingAttachedE_t>.metaTypes,
    nullptr
} };

void OverlayZStackingAttached::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OverlayZStackingAttached *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->zChanged(); break;
        case 1: _t->layerChanged(); break;
        case 2: _t->enqueueSignal(); break;
        case 3: _t->dispatchPendingSignal(); break;
        case 4: _t->updateParentPopup(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (OverlayZStackingAttached::*)()>(_a, &OverlayZStackingAttached::zChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (OverlayZStackingAttached::*)()>(_a, &OverlayZStackingAttached::layerChanged, 1))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<qreal*>(_v) = _t->z(); break;
        case 1: *reinterpret_cast<enum Layer*>(_v) = _t->layer(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setLayer(*reinterpret_cast<enum Layer*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *OverlayZStackingAttached::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OverlayZStackingAttached::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24OverlayZStackingAttachedE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int OverlayZStackingAttached::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void OverlayZStackingAttached::zChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void OverlayZStackingAttached::layerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
